@@ -4,9 +4,6 @@
 
 """Top-level package for python active versions."""
 import logging
-import pytomlpp
-
-from python_active_versions.bundle import get_bundle_dir
 
 try:
     from icecream import ic, install
@@ -19,12 +16,7 @@ except ImportError:  # Graceful fallback if IceCream isn't installed.
 
 __author__ = "Gabriele Pongelli"
 __email__ = "gabriele.pongelli@gmail.com"
-__version__ = "1.13.1"
+__version__ = "1.15.0"
 
-__description__ = None
-__project_name__ = None
-if not __description__ or not __project_name__:
-    with open(get_bundle_dir() / 'pyproject.toml', "rb") as pyproj:
-        pyproject = pytomlpp.load(pyproj)
-    __description__ = pyproject['tool']['poetry']['description']
-    __project_name__ = pyproject['tool']['poetry']['name']
+__description__ = "Gather active python versions."
+__project_name__ = "python-active-versions"
